@@ -1,14 +1,14 @@
 #ifndef lint
-static char rcsId[]="$Header: /cvs/gnome/gnome-libs/gtk-xmhtml/XmHTML.c,v 1.25 1998/05/09 17:05:20 kmaraas Exp $";
+static char rcsId[]="$Header: /cvs/gnome/gnome-libs/gtk-xmhtml/XmHTML.c,v 1.26 1998/11/29 00:06:34 unammx Exp $";
 #endif
 /*****
 * XmHTML.c : XmHTML main routines
 *
-* This file Version	$Revision: 1.25 $
+* This file Version	$Revision: 1.26 $
 *
 * Creation date:		Thu Nov 21 05:02:44 GMT+0100 1996
-* Last modification: 	$Date: 1998/05/09 17:05:20 $
-* By:					$Author: kmaraas $
+* Last modification: 	$Date: 1998/11/29 00:06:34 $
+* By:					$Author: unammx $
 * Current State:		$State: Exp $
 *
 * Author:				newt
@@ -35,6 +35,11 @@ static char rcsId[]="$Header: /cvs/gnome/gnome-libs/gtk-xmhtml/XmHTML.c,v 1.25 1
 /*****
 * ChangeLog 
 * $Log: XmHTML.c,v $
+* Revision 1.26  1998/11/29 00:06:34  unammx
+* 1998-11-28  Ronald de Man <deman@win.tue.nl>
+*
+* 	* XmHTML.c (_XmHTMLMoveToPos): Fix to the repaint.
+*
 * Revision 1.25  1998/05/09 17:05:20  kmaraas
 * 1998-05-09  Kjartan Maraas  <kmaraas@fib.hl.no>
 *
@@ -2857,8 +2862,9 @@ _XmHTMLMoveToPos(TWidget w, XmHTMLWidget html, int value)
 			html->html.scroll_y = value;
 
 			/* save new paint engine start */
-			html->html.paint_start = html->html.paint_end;
-
+/*			html->html.paint_start = html->html.paint_end; */
+			html->html.paint_end = html->html.paint_start;
+			
 			/* small increment */
 			if(inc < html->html.work_height)
 			{
