@@ -20,7 +20,25 @@
    write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
    Boston, MA 02111-1307, USA.  */
 
-#include <config.h>
+#ifdef HAVE_CONFIG_H
+#  include <config.h>
+#endif
+
+/* AIX requires this to be the first thing in the file.  */
+#ifndef __GNUC__
+# if HAVE_ALLOCA_H
+#  include <alloca.h>
+# else
+#  ifdef _AIX
+ #pragma alloca
+#  else
+#   ifndef alloca /* predefined by HP cc +Olibcalls */
+char *alloca ();
+#   endif
+#  endif
+# endif
+#endif
+
 #include <stdio.h>
 #include <string.h>
 #include <unistd.h>	/* unlink() */
@@ -37,6 +55,10 @@
 extern char *strndup (const char *s, size_t n);
 #endif
 
+#if !defined getc_unlocked && !defined HAVE_GETC_UNLOCKED
+# define getc_unlocked(fp) getc (fp)
+#endif
+
 #define STRSIZE 4096
 #define overflow (next == &CharBuffer [STRSIZE-1])
 
@@ -244,7 +266,7 @@ load (const char *file)
 		return NULL;
 	
 	state = FirstBrace;
-	while ((c = getc (f)) != EOF){
+	while ((c = getc_unlocked (f)) != EOF){
 		if (c == '\r')		/* Ignore Carriage Return */
 			continue;
 		
@@ -325,7 +347,7 @@ load (const char *file)
 	    
 		} /* switch */
 	
-	} /* while ((c = getc (f)) != EOF) */
+	} /* while ((c = getc_unlocked (f)) != EOF) */
 	if (c == EOF && state == KeyValue){
 		*next = '\0';
 		SecHeader->keys->value = decode_string_and_dup (CharBuffer);
@@ -1147,6 +1169,36 @@ gnome_config_drop_all (void)
 	Base = 0;
 }
 
+/**
+ * gnome_config_get_int:
+ * @path: A gnome configuration path to an item.
+ *
+ * Retrieves & returns the value of a configuration item as an integer.
+ */
+/**
+ * gnome_config_private_get_int:
+ * @path: A gnome configuration path to an item in the user-private namespace.
+ *
+ * Retrieves & returns the value of a configuration item as an integer.
+ * The item is retrieved from the user's private configuration storage area.
+ */
+/**
+ * gnome_config_get_int_with_default:
+ * @path: A gnome configuration path to an item.
+ * @def: A pointer to a flag that will be set if the default value for the item
+ * is returned.
+ *
+ * Retrieves & returns the value of a configuration item as an integer.
+ */
+/**
+ * gnome_config_private_get_int_with_default:
+ * @path: A gnome configuration path to an item in the user-private namespace.
+ * @def: A pointer to a flag that will be set if the default value for the item
+ * is returned.
+ *
+ * Retrieves & returns the value of a configuration item as an integer.
+ * The item is retrieved from the user's private configuration storage area.
+ */
 gint
 _gnome_config_get_int_with_default (const char *path, gboolean *def, gint priv)
 {
@@ -1167,6 +1219,37 @@ _gnome_config_get_int_with_default (const char *path, gboolean *def, gint priv)
 	return v;
 }
 
+/**
+ * gnome_config_get_float:
+ * @path: A gnome configuration path to an item.
+ *
+ * Retrieves & returns the value of a configuration item as a floating-point
+ * number.
+ */
+/**
+ * gnome_config_private_get_float:
+ * @path: A gnome configuration path to an item in the user-private namespace.
+ *
+ * Retrieves & returns the value of a configuration item as a floating-point number.
+ * The item is retrieved from the user's private configuration storage area.
+ */
+/**
+ * gnome_config_get_float_with_default:
+ * @path: A gnome configuration path to an item.
+ * @def: A pointer to a flag that will be set if the default value for the item
+ * is returned.
+ *
+ * Retrieves & returns the value of a configuration item as a floating-point number.
+ */
+/**
+ * gnome_config_private_get_float_with_default:
+ * @path: A gnome configuration path to an item in the user-private namespace.
+ * @def: A pointer to a flag that will be set if the default value for the item
+ * is returned.
+ *
+ * Retrieves & returns the value of a configuration item as a floating-point number.
+ * The item is retrieved from the user's private configuration storage area.
+ */
 gdouble
 _gnome_config_get_float_with_default (const char *path, gboolean *def, gint priv)
 {
@@ -1187,6 +1270,41 @@ _gnome_config_get_float_with_default (const char *path, gboolean *def, gint priv
 	return v;
 }
 
+/**
+ * gnome_config_get_translated_string:
+ * @path: A gnome configuration path to an item.
+ *
+ * Retrieves & returns the value of a configuration item as a string
+ * appropriate for the current language. The returned value should be
+ * g_free()'d when no longer needed.
+ */
+/**
+ * gnome_config_private_get_translated_string:
+ * @path: A gnome configuration path to an item in the user-private namespace.
+ *
+ * Retrieves & returns the value of a configuration item as a string appropriate for the current language. The returned value should be
+ * g_free()'d when no longer needed.
+ * The item is retrieved from the user's private configuration storage area.
+ */
+/**
+ * gnome_config_get_translated_string_with_default:
+ * @path: A gnome configuration path to an item.
+ * @def: A pointer to a flag that will be set if the default value for the item
+ * is returned.
+ *
+ * Retrieves & returns the value of a configuration item as a string appropriate for the current language. The returned value should be
+ * g_free()'d when no longer needed.
+ */
+/**
+ * gnome_config_private_get_translated_string_with_default:
+ * @path: A gnome configuration path to an item in the user-private namespace.
+ * @def: A pointer to a flag that will be set if the default value for the item
+ * is returned.
+ *
+ * Retrieves & returns the value of a configuration item as a string appropriate for the current language. The returned value should be
+ * g_free()'d when no longer needed.
+ * The item is retrieved from the user's private configuration storage area.
+ */
 char *
 _gnome_config_get_translated_string_with_default (const char *path,
 						  gboolean *def,
@@ -1243,6 +1361,45 @@ _gnome_config_get_translated_string_with_default (const char *path,
 	return value;
 }
 
+/**
+ * gnome_config_get_string:
+ * @path: A gnome configuration path to an item.
+ *
+ * Retrieves & returns the value of a configuration item as a string.
+ * The returned value should be
+ * g_free()'d when no longer needed.
+ */
+/**
+ * gnome_config_private_get_string:
+ * @path: A gnome configuration path to an item in the user-private namespace.
+ *
+ * Retrieves & returns the value of a configuration item as a
+ * string. The returned value should be g_free()'d when no longer
+ * needed.  The item is retrieved from the user's private
+ * configuration storage area.
+ */
+/**
+ * gnome_config_get_string_with_default:
+ * @path: A gnome configuration path to an item.
+ * @def: A pointer to a flag that will be set if the default value for the item
+ * is returned.
+ *
+ * Retrieves & returns the value of a configuration item as a string.
+ * The returned value should be g_free()'d when no longer needed.
+ *
+ */
+/**
+ * gnome_config_private_get_string_with_default:
+ * @path: A gnome configuration path to an item in the user-private namespace.
+ * @def: A pointer to a flag that will be set if the default value for the item
+ * is returned.
+ *
+ * Retrieves & returns the value of a configuration item as a string.
+ * The returned value should be g_free()'d when no longer needed.  The
+ * item is retrieved from the user's private configuration storage
+ * area.
+ *
+ */
 char *
 _gnome_config_get_string_with_default (const char *path, gboolean *def,
 				       gint priv)
@@ -1260,6 +1417,36 @@ _gnome_config_get_string_with_default (const char *path, gboolean *def,
 	return ret;
 }
 
+/**
+ * gnome_config_get_bool:
+ * @path: A gnome configuration path to an item.
+ *
+ * Retrieves & returns the value of a configuration item as a boolean.
+ */
+/**
+ * gnome_config_private_get_bool:
+ * @path: A gnome configuration path to an item in the user-private namespace.
+ *
+ * Retrieves & returns the value of a configuration item as a boolean.
+ * The item is retrieved from the user's private configuration storage area.
+ */
+/**
+ * gnome_config_get_bool_with_default:
+ * @path: A gnome configuration path to an item.
+ * @def: A pointer to a flag that will be set if the default value for the item
+ * is returned.
+ *
+ * Retrieves & returns the value of a configuration item as a boolean.
+ */
+/**
+ * gnome_config_private_get_bool_with_default:
+ * @path: A gnome configuration path to an item in the user-private namespace.
+ * @def: A pointer to a flag that will be set if the default value for the item
+ * is returned.
+ *
+ * Retrieves & returns the value of a configuration item as a boolean.
+ * The item is retrieved from the user's private configuration storage area.
+ */
 gboolean
 _gnome_config_get_bool_with_default (const char *path, gboolean *def,
 				     gint priv)
@@ -1290,8 +1477,15 @@ _gnome_config_get_bool_with_default (const char *path, gboolean *def,
 	return v;
 }
 
+/**
+ * gnome_config_make_vector:
+ * @string: The stringified vector to decode into 'argcp' and 'argvp'
+ * @argcp: Returns the number of elements in 'argvp'
+ * @argvp: Returns the array of strings found in 'rr'.
+ *
+ */
 void
-gnome_config_make_vector (const char *rr, int *argcp, char ***argvp)
+gnome_config_make_vector (const char *string, int *argcp, char ***argvp)
 {
 	char *p;
 	int count, esc_spcs;
@@ -1303,7 +1497,7 @@ gnome_config_make_vector (const char *rr, int *argcp, char ***argvp)
 	 */
 	count = 2;
 	space_seen = 0;
-	for (p = (char *) rr; *p; ++p) {
+	for (p = (char *) string; *p; ++p) {
 		/* The way that entries are constructed by
 		   gnome_config_set_vector ensures we'll never see an
 		   unpaired `\' at the end of a string.  So this is
@@ -1321,7 +1515,7 @@ gnome_config_make_vector (const char *rr, int *argcp, char ***argvp)
 	*argcp = count - 1;
 	*argvp = (char **) g_malloc0 (count * sizeof (char *));
 
-	p = (char *) rr;
+	p = (char *) string;
 	count = 0;
 	do {
 		char *tmp = p;
@@ -1341,6 +1535,53 @@ gnome_config_make_vector (const char *rr, int *argcp, char ***argvp)
 	} while (*p);
 }
 
+/**
+ * gnome_config_get_vector:
+ * @path: A gnome configuration path to an item.
+ * @argcp: Number of elements in the vector
+ * @argvp: Vector of strings
+ *
+ * Retrieves & returns the value of a configuration item as a string array.
+ * The returned value should be
+ * g_free()'d when no longer needed.
+ */
+/**
+ * gnome_config_private_get_vector:
+ * @path: A gnome configuration path to an item in the user-private namespace.
+ * @argcp: Number of elements in the vector
+ * @argvp: Vector of strings
+ *
+ * Retrieves & returns the value of a configuration item as a
+ * string. The returned value should be g_free()'d when no longer
+ * needed.  The item is retrieved from the user's private
+ * configuration storage area.
+ */
+/**
+ * gnome_config_get_vector_with_default:
+ * @path: A gnome configuration path to an item.
+ * @argcp: Number of elements in the vector
+ * @argvp: Vector of strings
+ * @def: A pointer to a flag that will be set if the default value for the item
+ * is returned.
+ *
+ * Retrieves & returns the value of a configuration item as a string array.
+ * The returned value should be g_free()'d when no longer needed.
+ *
+ */
+/**
+ * gnome_config_private_get_vector_with_default:
+ * @path: A gnome configuration path to an item in the user-private namespace.
+ * @argcp: Number of elements in the vector
+ * @argvp: Vector of strings
+ * @def: A pointer to a flag that will be set if the default value for the item
+ * is returned.
+ *
+ * Retrieves & returns the value of a configuration item as a string array.
+ * The returned value should be g_free()'d when no longer needed.  The
+ * item is retrieved from the user's private configuration storage
+ * area.
+ *
+ */
 void
 _gnome_config_get_vector_with_default (const char *path, int *argcp,
 				       char ***argvp, gboolean *def, gint priv)
@@ -1363,7 +1604,7 @@ _gnome_config_get_vector_with_default (const char *path, int *argcp,
  * gnome_config_set_translated_string:
  * @path: a gnome configuration path to a key
  * @value: a string value to set.
- *
+ * 
  * Stores the string value @new_value in the file/section/key defined
  * by the @path on the proper section for the current language set by
  * by the user.
@@ -1511,6 +1752,15 @@ gnome_config_assemble_vector (int argc, const char *const argv [])
 	return value;
 }
 
+/**
+ * gnome_config_set_vector:
+ * @path: a gnome configuration path to a key
+ * @argc: the number of elements in @argv
+ * @argv: a string array holding the data to store.
+ *
+ * Stores vector @argv in the file/section/key defined by
+ * @path.
+ */
 void
 _gnome_config_set_vector (const char *path, int argc,
 			  const char *const argv[],
@@ -1548,7 +1798,7 @@ gnome_config_push_prefix (const char *path)
 /**
  * gnome_config_pop_prefix:
  *
- * Call this routine to stop using the configuration prefix
+ * Call this routine to remove the current configuration prefix from the stack.
  */
 void
 gnome_config_pop_prefix (void)
@@ -1561,12 +1811,26 @@ gnome_config_pop_prefix (void)
 	}
 }
 
+/**
+ * gnome_config_set_set_handler
+ * @func: Obsolete
+ * @data: Obsolete
+ *
+ * Internal Obsolete.
+ */
 void
 gnome_config_set_set_handler(void (*func)(void *),void *data)
 {
 	g_warning("gnome_config_set_set_handler is obscolete and has no replacement");
 }
 
+/**
+ * gnome_config_set_sync_handler
+ * @func: obsolete
+ * @data: obsolete
+ *
+ * Internal routine
+ */
 void
 gnome_config_set_sync_handler(void (*func)(void *),void *data)
 {
