@@ -46,12 +46,17 @@ typedef enum {
 	GNOME_APP_UI_BUILDER_DATA,	/* Specifies the builder data for the 
 					   following entries, see code for 
 					   further info */
-	GNOME_APP_UI_ITEM_CONFIGURABLE  /* A configurable menu item. */
+	GNOME_APP_UI_ITEM_CONFIGURABLE, /* A configurable menu item. */
 	/* one should be careful when using 
 	 * gnome_app_create_*_[custom|interp|with_data]() functions with 
 	 * GnomeUIInfo arrays containing GNOME_APP_UI_BUILDER_DATA items since 
 	 * their GnomeUIBuilderData structures completely override the ones 
 	 * generated or supplied by the above functions. */
+	GNOME_APP_UI_SUBTREE_STOCK	/* Item that defines a 
+					   subtree/submenu, same as GNOME_APP_UI_SUBTREE,
+					   but the texts should be looked up in the
+					   gnome-libs catalog
+					*/
 } GnomeUIInfoType;
 
 /* If you insert a value into this enum it'll break configurations all
@@ -254,11 +259,11 @@ typedef struct {
         { GNOME_APP_UI_ITEM_CONFIGURABLE, label, tip,                       \
           cb, (gpointer)(data), NULL,                                       \
           GNOME_APP_PIXMAP_NONE, NULL,                                      \
-          GNOME_APP_CONFIGURABLE_ITEM_NEW, 0, NULL }
+          GNOME_APP_CONFIGURABLE_ITEM_NEW, (GdkModifierType) 0, NULL }
 
 /* If you have more then one New type, use this tree */
 #define GNOMEUIINFO_MENU_NEW_SUBTREE(tree)                                  \
-        { GNOME_APP_UI_SUBTREE, N_("_New"), NULL, tree, NULL, NULL,         \
+        { GNOME_APP_UI_SUBTREE_STOCK, N_("_New"), NULL, tree, NULL, NULL,   \
           GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_NEW,                     \
           GNOME_KEY_NAME_NEW, GNOME_KEY_MOD_NEW, NULL }
 
@@ -266,49 +271,49 @@ typedef struct {
         { GNOME_APP_UI_ITEM_CONFIGURABLE, NULL, NULL,                       \
           cb, (gpointer)(data), NULL,                                       \
           GNOME_APP_PIXMAP_NONE, NULL,                                      \
-          GNOME_APP_CONFIGURABLE_ITEM_OPEN, 0, NULL }
+          GNOME_APP_CONFIGURABLE_ITEM_OPEN, (GdkModifierType) 0, NULL }
 
 #define GNOMEUIINFO_MENU_SAVE_ITEM(cb, data)                                \
         { GNOME_APP_UI_ITEM_CONFIGURABLE, NULL, NULL,                       \
           cb, (gpointer)(data), NULL,                                       \
           GNOME_APP_PIXMAP_NONE, NULL,                                      \
-          GNOME_APP_CONFIGURABLE_ITEM_SAVE, 0, NULL }
+          GNOME_APP_CONFIGURABLE_ITEM_SAVE, (GdkModifierType) 0, NULL }
 
 #define GNOMEUIINFO_MENU_SAVE_AS_ITEM(cb, data)                             \
         { GNOME_APP_UI_ITEM_CONFIGURABLE, NULL, NULL,                       \
           cb, (gpointer)(data), NULL,                                       \
           GNOME_APP_PIXMAP_NONE, NULL,                                      \
-          GNOME_APP_CONFIGURABLE_ITEM_SAVE_AS, 0, NULL }
+          GNOME_APP_CONFIGURABLE_ITEM_SAVE_AS, (GdkModifierType) 0, NULL }
 
 #define GNOMEUIINFO_MENU_REVERT_ITEM(cb, data)                              \
         { GNOME_APP_UI_ITEM_CONFIGURABLE, NULL, NULL,                       \
           cb, (gpointer)(data), NULL,                                       \
           GNOME_APP_PIXMAP_NONE, NULL,                                      \
-          GNOME_APP_CONFIGURABLE_ITEM_REVERT, 0, NULL }
+          GNOME_APP_CONFIGURABLE_ITEM_REVERT, (GdkModifierType) 0, NULL }
 
 #define GNOMEUIINFO_MENU_PRINT_ITEM(cb, data)                               \
         { GNOME_APP_UI_ITEM_CONFIGURABLE, NULL, NULL,                       \
           cb, (gpointer)(data), NULL,                                       \
           GNOME_APP_PIXMAP_NONE, NULL,                                      \
-          GNOME_APP_CONFIGURABLE_ITEM_PRINT, 0, NULL }
+          GNOME_APP_CONFIGURABLE_ITEM_PRINT, (GdkModifierType) 0, NULL }
 
 #define GNOMEUIINFO_MENU_PRINT_SETUP_ITEM(cb, data)                         \
         { GNOME_APP_UI_ITEM_CONFIGURABLE, NULL, NULL,                       \
           cb, (gpointer)(data), NULL,                                       \
           GNOME_APP_PIXMAP_NONE, NULL,                                      \
-          GNOME_APP_CONFIGURABLE_ITEM_PRINT_SETUP, 0, NULL }
+          GNOME_APP_CONFIGURABLE_ITEM_PRINT_SETUP, (GdkModifierType) 0, NULL }
 
 #define GNOMEUIINFO_MENU_CLOSE_ITEM(cb, data)                               \
         { GNOME_APP_UI_ITEM_CONFIGURABLE, NULL, NULL,                       \
           cb, (gpointer)(data), NULL,                                       \
           GNOME_APP_PIXMAP_NONE, NULL,                                      \
-          GNOME_APP_CONFIGURABLE_ITEM_CLOSE, 0, NULL }
+          GNOME_APP_CONFIGURABLE_ITEM_CLOSE, (GdkModifierType) 0, NULL }
 
 #define GNOMEUIINFO_MENU_EXIT_ITEM(cb, data)                                \
         { GNOME_APP_UI_ITEM_CONFIGURABLE, NULL, NULL,                       \
           cb, (gpointer)(data), NULL,                                       \
           GNOME_APP_PIXMAP_NONE, NULL,                                      \
-          GNOME_APP_CONFIGURABLE_ITEM_EXIT, 0, NULL }
+          GNOME_APP_CONFIGURABLE_ITEM_EXIT, (GdkModifierType) 0, NULL }
 /*
  * The "Edit" menu
  */
@@ -317,67 +322,67 @@ typedef struct {
         { GNOME_APP_UI_ITEM_CONFIGURABLE, NULL, NULL,                       \
           cb, (gpointer)(data), NULL,                                       \
           GNOME_APP_PIXMAP_NONE, NULL,                                      \
-          GNOME_APP_CONFIGURABLE_ITEM_CUT, 0, NULL }
+          GNOME_APP_CONFIGURABLE_ITEM_CUT, (GdkModifierType) 0, NULL }
 
 #define GNOMEUIINFO_MENU_COPY_ITEM(cb, data)                                \
         { GNOME_APP_UI_ITEM_CONFIGURABLE, NULL, NULL,                       \
           cb, (gpointer)(data), NULL,                                       \
           GNOME_APP_PIXMAP_NONE, NULL,                                      \
-          GNOME_APP_CONFIGURABLE_ITEM_COPY, 0, NULL }
+          GNOME_APP_CONFIGURABLE_ITEM_COPY, (GdkModifierType) 0, NULL }
 
 #define GNOMEUIINFO_MENU_PASTE_ITEM(cb, data)                               \
         { GNOME_APP_UI_ITEM_CONFIGURABLE, NULL, NULL,                       \
           cb, (gpointer)(data), NULL,                                       \
           GNOME_APP_PIXMAP_NONE, NULL,                                      \
-          GNOME_APP_CONFIGURABLE_ITEM_PASTE, 0, NULL }
+          GNOME_APP_CONFIGURABLE_ITEM_PASTE, (GdkModifierType) 0, NULL }
 
 #define GNOMEUIINFO_MENU_SELECT_ALL_ITEM(cb, data)                          \
         { GNOME_APP_UI_ITEM_CONFIGURABLE, NULL, NULL,                       \
           cb, (gpointer)(data), NULL,                                       \
           GNOME_APP_PIXMAP_NONE, NULL,                                      \
-          GNOME_APP_CONFIGURABLE_ITEM_SELECT_ALL, 0, NULL }
+          GNOME_APP_CONFIGURABLE_ITEM_SELECT_ALL, (GdkModifierType) 0, NULL }
 
 #define GNOMEUIINFO_MENU_CLEAR_ITEM(cb, data)                               \
         { GNOME_APP_UI_ITEM_CONFIGURABLE, NULL, NULL,                       \
           cb, (gpointer)(data), NULL,                                       \
           GNOME_APP_PIXMAP_NONE, NULL,                                      \
-          GNOME_APP_CONFIGURABLE_ITEM_CLEAR, 0, NULL }
+          GNOME_APP_CONFIGURABLE_ITEM_CLEAR, (GdkModifierType) 0, NULL }
 
 #define GNOMEUIINFO_MENU_UNDO_ITEM(cb, data)                                \
         { GNOME_APP_UI_ITEM_CONFIGURABLE, NULL, NULL,                       \
           cb, (gpointer)(data), NULL,                                       \
           GNOME_APP_PIXMAP_NONE, NULL,                                      \
-          GNOME_APP_CONFIGURABLE_ITEM_UNDO, 0, NULL }
+          GNOME_APP_CONFIGURABLE_ITEM_UNDO, (GdkModifierType) 0, NULL }
 
 #define GNOMEUIINFO_MENU_REDO_ITEM(cb, data)                                \
         { GNOME_APP_UI_ITEM_CONFIGURABLE, NULL, NULL,                       \
           cb, (gpointer)(data), NULL,                                       \
           GNOME_APP_PIXMAP_NONE, NULL,                                      \
-          GNOME_APP_CONFIGURABLE_ITEM_REDO, 0, NULL }
+          GNOME_APP_CONFIGURABLE_ITEM_REDO, (GdkModifierType) 0, NULL }
 
 #define GNOMEUIINFO_MENU_FIND_ITEM(cb, data)                                \
         { GNOME_APP_UI_ITEM_CONFIGURABLE, NULL, NULL,                       \
           cb, (gpointer)(data), NULL,                                       \
           GNOME_APP_PIXMAP_NONE, NULL,                                      \
-          GNOME_APP_CONFIGURABLE_ITEM_FIND, 0, NULL }
+          GNOME_APP_CONFIGURABLE_ITEM_FIND, (GdkModifierType) 0, NULL }
 
 #define GNOMEUIINFO_MENU_FIND_AGAIN_ITEM(cb, data)                          \
         { GNOME_APP_UI_ITEM_CONFIGURABLE, NULL, NULL,                       \
           cb, (gpointer)(data), NULL,                                       \
           GNOME_APP_PIXMAP_NONE, NULL,                                      \
-          GNOME_APP_CONFIGURABLE_ITEM_FIND_AGAIN, 0, NULL }
+          GNOME_APP_CONFIGURABLE_ITEM_FIND_AGAIN, (GdkModifierType) 0, NULL }
 
 #define GNOMEUIINFO_MENU_REPLACE_ITEM(cb, data)                             \
         { GNOME_APP_UI_ITEM_CONFIGURABLE, NULL, NULL,                       \
           cb, (gpointer)(data), NULL,                                       \
           GNOME_APP_PIXMAP_NONE, NULL,                                      \
-          GNOME_APP_CONFIGURABLE_ITEM_REPLACE, 0, NULL }
+          GNOME_APP_CONFIGURABLE_ITEM_REPLACE, (GdkModifierType) 0, NULL }
 
 #define GNOMEUIINFO_MENU_PROPERTIES_ITEM(cb, data)                          \
         { GNOME_APP_UI_ITEM_CONFIGURABLE, NULL, NULL,                       \
           cb, (gpointer)(data), NULL,                                       \
           GNOME_APP_PIXMAP_NONE, NULL,                                      \
-          GNOME_APP_CONFIGURABLE_ITEM_PROPERTIES, 0, NULL }
+          GNOME_APP_CONFIGURABLE_ITEM_PROPERTIES, (GdkModifierType) 0, NULL }
 
 /*
  * The Settings menu
@@ -386,7 +391,7 @@ typedef struct {
         { GNOME_APP_UI_ITEM_CONFIGURABLE, NULL, NULL,                       \
           cb, (gpointer)(data), NULL,                                       \
           GNOME_APP_PIXMAP_NONE, NULL,                                      \
-          GNOME_APP_CONFIGURABLE_ITEM_PREFERENCES, 0, NULL }
+          GNOME_APP_CONFIGURABLE_ITEM_PREFERENCES, (GdkModifierType) 0, NULL }
 
 /*
  * The Windows menu
@@ -395,13 +400,13 @@ typedef struct {
         { GNOME_APP_UI_ITEM_CONFIGURABLE, NULL, NULL,                       \
           cb, (gpointer)(data), NULL,                                       \
           GNOME_APP_PIXMAP_NONE, NULL,                                      \
-          GNOME_APP_CONFIGURABLE_ITEM_NEW_WINDOW, 0, NULL }
+          GNOME_APP_CONFIGURABLE_ITEM_NEW_WINDOW, (GdkModifierType) 0, NULL }
 
 #define GNOMEUIINFO_MENU_CLOSE_WINDOW_ITEM(cb, data)                        \
         { GNOME_APP_UI_ITEM_CONFIGURABLE, NULL, NULL,                       \
           cb, (gpointer)(data), NULL,                                       \
           GNOME_APP_PIXMAP_NONE, NULL,                                      \
-          GNOME_APP_CONFIGURABLE_ITEM_CLOSE_WINDOW, 0, NULL }
+          GNOME_APP_CONFIGURABLE_ITEM_CLOSE_WINDOW, (GdkModifierType) 0, NULL }
 
 /*
  * And the "Help" menu
@@ -410,7 +415,7 @@ typedef struct {
         { GNOME_APP_UI_ITEM_CONFIGURABLE, NULL, NULL,                       \
           cb, (gpointer)(data), NULL,                                       \
           GNOME_APP_PIXMAP_NONE, NULL,                                      \
-          GNOME_APP_CONFIGURABLE_ITEM_ABOUT, 0, NULL }
+          GNOME_APP_CONFIGURABLE_ITEM_ABOUT, (GdkModifierType) 0, NULL }
 
 /* 
  * The "Game" menu
@@ -420,89 +425,93 @@ typedef struct {
         { GNOME_APP_UI_ITEM_CONFIGURABLE, NULL, NULL,                       \
           cb, (gpointer)(data), NULL,                                       \
           GNOME_APP_PIXMAP_NONE, NULL,                                      \
-          GNOME_APP_CONFIGURABLE_ITEM_NEW_GAME, 0, NULL }
+          GNOME_APP_CONFIGURABLE_ITEM_NEW_GAME, (GdkModifierType) 0, NULL }
 	  
 #define GNOMEUIINFO_MENU_PAUSE_GAME_ITEM(cb, data)                            \
         { GNOME_APP_UI_ITEM_CONFIGURABLE, NULL, NULL,                       \
           cb, (gpointer)(data), NULL,                                       \
           GNOME_APP_PIXMAP_NONE, NULL,                                      \
-          GNOME_APP_CONFIGURABLE_ITEM_PAUSE_GAME, 0, NULL }
+          GNOME_APP_CONFIGURABLE_ITEM_PAUSE_GAME, (GdkModifierType) 0, NULL }
 	  
 #define GNOMEUIINFO_MENU_RESTART_GAME_ITEM(cb, data)                            \
         { GNOME_APP_UI_ITEM_CONFIGURABLE, NULL, NULL,                       \
           cb, (gpointer)(data), NULL,                                       \
           GNOME_APP_PIXMAP_NONE, NULL,                                      \
-          GNOME_APP_CONFIGURABLE_ITEM_RESTART_GAME, 0, NULL }
+          GNOME_APP_CONFIGURABLE_ITEM_RESTART_GAME, (GdkModifierType) 0, NULL }
 	  
 #define GNOMEUIINFO_MENU_UNDO_MOVE_ITEM(cb, data)                            \
         { GNOME_APP_UI_ITEM_CONFIGURABLE, NULL, NULL,                       \
           cb, (gpointer)(data), NULL,                                       \
           GNOME_APP_PIXMAP_NONE, NULL,                                      \
-          GNOME_APP_CONFIGURABLE_ITEM_UNDO_MOVE, 0, NULL }
+          GNOME_APP_CONFIGURABLE_ITEM_UNDO_MOVE, (GdkModifierType) 0, NULL }
 	  
 #define GNOMEUIINFO_MENU_REDO_MOVE_ITEM(cb, data)                            \
         { GNOME_APP_UI_ITEM_CONFIGURABLE, NULL, NULL,                       \
           cb, (gpointer)(data), NULL,                                       \
           GNOME_APP_PIXMAP_NONE, NULL,                                      \
-          GNOME_APP_CONFIGURABLE_ITEM_REDO_MOVE, 0, NULL }
+          GNOME_APP_CONFIGURABLE_ITEM_REDO_MOVE, (GdkModifierType) 0, NULL }
 	  
 #define GNOMEUIINFO_MENU_HINT_ITEM(cb, data)                            \
         { GNOME_APP_UI_ITEM_CONFIGURABLE, NULL, NULL,                       \
           cb, (gpointer)(data), NULL,                                       \
           GNOME_APP_PIXMAP_NONE, NULL,                                      \
-          GNOME_APP_CONFIGURABLE_ITEM_HINT, 0, NULL }
+          GNOME_APP_CONFIGURABLE_ITEM_HINT, (GdkModifierType) 0, NULL }
 	  
 #define GNOMEUIINFO_MENU_SCORES_ITEM(cb, data)                            \
         { GNOME_APP_UI_ITEM_CONFIGURABLE, NULL, NULL,                       \
           cb, (gpointer)(data), NULL,                                       \
           GNOME_APP_PIXMAP_NONE, NULL,                                      \
-          GNOME_APP_CONFIGURABLE_ITEM_SCORES, 0, NULL }
+          GNOME_APP_CONFIGURABLE_ITEM_SCORES, (GdkModifierType) 0, NULL }
 	  
 #define GNOMEUIINFO_MENU_END_GAME_ITEM(cb, data)                            \
         { GNOME_APP_UI_ITEM_CONFIGURABLE, NULL, NULL,                       \
           cb, (gpointer)(data), NULL,                                       \
           GNOME_APP_PIXMAP_NONE, NULL,                                      \
-          GNOME_APP_CONFIGURABLE_ITEM_END_GAME, 0, NULL }
-	  
+          GNOME_APP_CONFIGURABLE_ITEM_END_GAME, (GdkModifierType) 0, NULL }
+
+char * gnome_app_helper_gettext (char *string);
+
+#define D_(x) gnome_app_helper_gettext(x)
+
 /* Some standard menus */
 #define GNOMEUIINFO_MENU_FILE_TREE(tree) \
-	{ GNOME_APP_UI_SUBTREE, N_("_File"), NULL, tree, NULL, NULL, \
+	{ GNOME_APP_UI_SUBTREE_STOCK, N_("_File"), NULL, tree, NULL, NULL, \
 		(GnomeUIPixmapType) 0, NULL, 0,	(GdkModifierType) 0, NULL }
 #define GNOMEUIINFO_MENU_EDIT_TREE(tree) \
-	{ GNOME_APP_UI_SUBTREE, N_("_Edit"), NULL, tree, NULL, NULL, \
+	{ GNOME_APP_UI_SUBTREE_STOCK, N_("_Edit"), NULL, tree, NULL, NULL, \
 		(GnomeUIPixmapType) 0, NULL, 0,	(GdkModifierType) 0, NULL }
 #define GNOMEUIINFO_MENU_VIEW_TREE(tree) \
-	{ GNOME_APP_UI_SUBTREE, N_("_View"), NULL, tree, NULL, NULL, \
+	{ GNOME_APP_UI_SUBTREE_STOCK, N_("_View"), NULL, tree, NULL, NULL, \
 		(GnomeUIPixmapType) 0, NULL, 0,	(GdkModifierType) 0, NULL }
 #define GNOMEUIINFO_MENU_SETTINGS_TREE(tree) \
-	{ GNOME_APP_UI_SUBTREE, N_("_Settings"), NULL, tree, NULL, NULL, \
+	{ GNOME_APP_UI_SUBTREE_STOCK, N_("_Settings"), NULL, tree, NULL, NULL, \
 		(GnomeUIPixmapType) 0, NULL, 0,	(GdkModifierType) 0, NULL }
 #define GNOMEUIINFO_MENU_FILES_TREE(tree) \
-	{ GNOME_APP_UI_SUBTREE, N_("Fi_les"), NULL, tree, NULL, NULL, \
+	{ GNOME_APP_UI_SUBTREE_STOCK, N_("Fi_les"), NULL, tree, NULL, NULL, \
 		(GnomeUIPixmapType) 0, NULL, 0,	(GdkModifierType) 0, NULL }
 #define GNOMEUIINFO_MENU_WINDOWS_TREE(tree) \
-	{ GNOME_APP_UI_SUBTREE, N_("_Windows"), NULL, tree, NULL, NULL, \
+	{ GNOME_APP_UI_SUBTREE_STOCK, N_("_Windows"), NULL, tree, NULL, NULL, \
 		(GnomeUIPixmapType) 0, NULL, 0,	(GdkModifierType) 0, NULL }
 #define GNOMEUIINFO_MENU_HELP_TREE(tree) \
-	{ GNOME_APP_UI_SUBTREE, N_("_Help"), NULL, tree, NULL, NULL, \
+	{ GNOME_APP_UI_SUBTREE_STOCK, N_("_Help"), NULL, tree, NULL, NULL, \
 		(GnomeUIPixmapType) 0, NULL, 0,	(GdkModifierType) 0, NULL }
 #define GNOMEUIINFO_MENU_GAME_TREE(tree) \
-	{ GNOME_APP_UI_SUBTREE, N_("_Game"), NULL, tree, NULL, NULL, \
+	{ GNOME_APP_UI_SUBTREE_STOCK, N_("_Game"), NULL, tree, NULL, NULL, \
 		(GnomeUIPixmapType) 0, NULL, 0,	(GdkModifierType) 0, NULL }
 		
 /*these are strings to be used for paths when working with the menus stuff*/
-#define GNOME_MENU_FILE_STRING _("_File")
-#define GNOME_MENU_FILE_PATH _("_File/")
-#define GNOME_MENU_EDIT_STRING _("_Edit")
-#define GNOME_MENU_EDIT_PATH _("_Edit/")
-#define GNOME_MENU_VIEW_STRING _("_View")
-#define GNOME_MENU_VIEW_PATH _("_View/")
-#define GNOME_MENU_SETTINGS_STRING _("_Settings")
-#define GNOME_MENU_SETTINGS_PATH _("_Settings/")
-#define GNOME_MENU_FILES_STRING _("File_s")
-#define GNOME_MENU_FILES_PATH _("File_s/")
-#define GNOME_MENU_WINDOWS_STRING _("_Windows")
-#define GNOME_MENU_WINDOWS_PATH _("_Windows/")
+#define GNOME_MENU_FILE_STRING D_("_File")
+#define GNOME_MENU_FILE_PATH D_("_File/")
+#define GNOME_MENU_EDIT_STRING D_("_Edit")
+#define GNOME_MENU_EDIT_PATH D_("_Edit/")
+#define GNOME_MENU_VIEW_STRING D_("_View")
+#define GNOME_MENU_VIEW_PATH D_("_View/")
+#define GNOME_MENU_SETTINGS_STRING D_("_Settings")
+#define GNOME_MENU_SETTINGS_PATH D_("_Settings/")
+#define GNOME_MENU_FILES_STRING D_("Fi_les")
+#define GNOME_MENU_FILES_PATH D_("Fi_les/")
+#define GNOME_MENU_WINDOWS_STRING D_("_Windows")
+#define GNOME_MENU_WINDOWS_PATH D_("_Windows/")
 
 
 /* Types useful to language bindings */
@@ -533,6 +542,14 @@ void gnome_app_fill_menu (GtkMenuShell *menu_shell, GnomeUIInfo *uiinfo,
 			  GtkAccelGroup *accel_group,
 			  gboolean insert_shortcuts, gint pos);
 
+/* Same as gnome_app_fill_menu, but sets all the user data pointers to
+ * the specified value.
+ */
+void gnome_app_fill_menu_with_data (GtkMenuShell *menu_shell, GnomeUIInfo *uiinfo,
+				    GtkAccelGroup *accel_group,
+				    gboolean insert_shortcuts, gint pos,
+				    gpointer user_data);
+
 /* Fills the specified menu shell with items created from the specified
  * info, inserting them from item no. pos on and using the specified
  * builder data -- this is intended for language bindings.  If the
@@ -583,6 +600,12 @@ void gnome_app_create_menus_custom (GnomeApp *app, GnomeUIInfo *uiinfo, GnomeUIB
  */
 void gnome_app_fill_toolbar (GtkToolbar *toolbar, GnomeUIInfo *uiinfo, GtkAccelGroup *accel_group);
 
+/* Same as gnome_app_fill_toolbar, but sets all the user data pointers
+ * to the specified value.
+ */
+void gnome_app_fill_toolbar_with_data (GtkToolbar *toolbar, GnomeUIInfo *uiinfo,
+				       GtkAccelGroup *accel_group, gpointer user_data);
+
 /* Fills the specified toolbar with buttons created from the specified info, using the specified
  * builder data -- this is intended for language bindings.  If accel_group is not NULL, then the
  * items' accelerator keys are put into it.
