@@ -1193,9 +1193,9 @@ gnome_dock_item_handle_size_request (GnomeDockItem *item,
     gtk_widget_size_request (bin->child, requisition);
 
   if (item->orientation == GTK_ORIENTATION_HORIZONTAL)
-    requisition->width = DRAG_HANDLE_SIZE;
+    requisition->width += DRAG_HANDLE_SIZE;
   else
-    requisition->height = DRAG_HANDLE_SIZE;
+    requisition->height += DRAG_HANDLE_SIZE;
 
   requisition->width += container->border_width * 2;
   requisition->height += container->border_width * 2;
