@@ -100,6 +100,7 @@ BEGIN_GNOME_DECLS
 #define GNOME_STOCK_PIXMAP_CUT         "Cut"
 #define GNOME_STOCK_PIXMAP_COPY        "Copy"
 #define GNOME_STOCK_PIXMAP_PASTE       "Paste"
+#define GNOME_STOCK_PIXMAP_CLEAR       "Clear"
 #define GNOME_STOCK_PIXMAP_PROPERTIES  "Properties"
 #define GNOME_STOCK_PIXMAP_PREFERENCES "Preferences"
 #define GNOME_STOCK_PIXMAP_HELP        "Help"
@@ -152,18 +153,31 @@ BEGIN_GNOME_DECLS
 #define GNOME_STOCK_PIXMAP_FONT        "Font"
 #define GNOME_STOCK_PIXMAP_EXEC        "Exec"
 
-#define GNOME_STOCK_PIXMAP_ALIGN_LEFT  "Left"
-#define GNOME_STOCK_PIXMAP_ALIGN_RIGHT "Right"
-#define GNOME_STOCK_PIXMAP_ALIGN_CENTER "Center"
+#define GNOME_STOCK_PIXMAP_ALIGN_LEFT    "Left"
+#define GNOME_STOCK_PIXMAP_ALIGN_RIGHT   "Right"
+#define GNOME_STOCK_PIXMAP_ALIGN_CENTER  "Center"
 #define GNOME_STOCK_PIXMAP_ALIGN_JUSTIFY "Justify"
 
-#define GNOME_STOCK_PIXMAP_TEXT_BOLD    "Bold"
-#define GNOME_STOCK_PIXMAP_TEXT_ITALIC  "Italic"
+#define GNOME_STOCK_PIXMAP_TEXT_BOLD      "Bold"
+#define GNOME_STOCK_PIXMAP_TEXT_ITALIC    "Italic"
 #define GNOME_STOCK_PIXMAP_TEXT_UNDERLINE "Underline"
 #define GNOME_STOCK_PIXMAP_TEXT_STRIKEOUT "Strikeout"
 
+#define GNOME_STOCK_PIXMAP_TEXT_INDENT "Text Indent"
+#define GNOME_STOCK_PIXMAP_TEXT_UNINDENT "Text Unindent"
+
 #define GNOME_STOCK_PIXMAP_EXIT        GNOME_STOCK_PIXMAP_QUIT
 
+#define GNOME_STOCK_PIXMAP_COLORSELECTOR "Color Select"
+
+#define GNOME_STOCK_PIXMAP_ADD    "Add"
+#define GNOME_STOCK_PIXMAP_REMOVE "Remove"
+
+#define GNOME_STOCK_PIXMAP_TABLE_BORDERS "Table Borders"
+#define GNOME_STOCK_PIXMAP_TABLE_FILL "Table Fill"
+
+#define GNOME_STOCK_PIXMAP_TEXT_BULLETED_LIST "Text Bulleted List"
+#define GNOME_STOCK_PIXMAP_TEXT_NUMBERED_LIST "Text Numbered List"
 
 /* The basic pixmap version of an icon. */
 
